IMAGE_FEATURES = " ssh-server-openssh"

IMAGE_INSTALL = "packagegroup-core-boot \
		packagegroup-base \
		${CORE_IMAGE_EXTRA_INSTALL} \
		kernel-modules \
		wpa-supplicant \
		shape shapeware \
		networkmanager \
		monit \
		nano \
		sudo \
		mosquitto \
		mosquitto-clients \
		avahi-daemon \
		rsyslog \
		networkmanager \
		modemmanager \
		wireguard-tools \
		wireguard-client-config \
		usb-modeswitch \
		coreutils \
		volatile-binds \
		logrotate \
		watchdog \
		watchdog-config \
		pixla-client \
		jq \
		htop \
		bash \
		bash-completion \
		haveged \
		rng-tools \
		iotop \
		fake-hwclock \
		tzdata \
		tzdata-europe \
		wget rsync curl \
		screen \
		systemd-conf \
		mender-connect \
		base-config \
		googletest \
		i2c-tools \
		util-linux \
"

GLIBC_GENERATE_LOCALES = "en_GB.UTF-8 en_US.UTF-8"

IMAGE_LINGUAS ?= "en-gb"

inherit core-image extrausers

# set admin password for all images
EXTRA_USERS_PARAMS = "useradd -P admin admin; \
	usermod -a -G root,sudo admin; \
	groupadd admin; "

# config files to be stored in persistent partition
PERSISTENT_CONF_FILES_SHADOW = " \
  ${sysconfdir}/shadow \
  ${sysconfdir}/passwd \
"

PERSISTENT_CONF_FILES = " \
        ${sysconfdir}/localtime \
				${sysconfdir}/nginx/sites-available/default_server \
				${sysconfdir}/nginx/sites-enabled \
"

PERSISTENT_CONF_FILES_SYSTEMD = " \
	${sysconfdir}/systemd/system \
"

# look through PERSISTENT_CONF_FILES, create related symbolic links to /data,
# create a empty file in /data/ if the original config file does not exist.
set_user_group_append() {
    for conf in ${PERSISTENT_CONF_FILES_SHADOW}; do
        mkdir -p ${IMAGE_ROOTFS}/$(dirname $conf)
        mkdir -p ${IMAGE_ROOTFS}/data$(dirname $conf)
        if [ -e ${IMAGE_ROOTFS}$conf ]; then
            mv ${IMAGE_ROOTFS}$conf ${IMAGE_ROOTFS}/data$conf
        else
            # conf is a directory
            if echo $conf | grep -o -q '^.*/$'; then
                mkdir -p ${IMAGE_ROOTFS}/data$conf
            else
                touch ${IMAGE_ROOTFS}/data$conf
            fi
        fi
        ln -sf /data$conf ${IMAGE_ROOTFS}$(echo $conf | sed -e 's/\/$//')
    done
}

create_persistent_symbolic_links() {
    for conf in ${PERSISTENT_CONF_FILES}; do
        mkdir -p ${IMAGE_ROOTFS}/$(dirname $conf)
        mkdir -p ${IMAGE_ROOTFS}/data$(dirname $conf)
        if [ -e ${IMAGE_ROOTFS}$conf ]; then
            mv ${IMAGE_ROOTFS}$conf ${IMAGE_ROOTFS}/data$conf
        else
	    # conf is a directory
	    if echo $conf | grep -o -q '^.*/$'; then
	        mkdir -p ${IMAGE_ROOTFS}/data$conf
	    else
		touch ${IMAGE_ROOTFS}/data$conf
	    fi
	fi
	ln -sf /data$conf ${IMAGE_ROOTFS}$(echo $conf | sed -e 's/\/$//')
    done

    # Handle persistent logging, store log information to /data/storage/log
    # rather than /var/log.
    if [ ${@ oe.types.boolean('${VOLATILE_LOG_DIR}') } = False ]; then
        mkdir -p ${IMAGE_ROOTFS}/data/storage
        mv ${IMAGE_ROOTFS}/var/log ${IMAGE_ROOTFS}/data/storage
        ln -sf /data/storage/log ${IMAGE_ROOTFS}/var/log
    fi
}

systemd_preset_all_append() {
    for conf in ${PERSISTENT_CONF_FILES_SYSTEMD}; do
        mkdir -p ${IMAGE_ROOTFS}/$(dirname $conf)
        mkdir -p ${IMAGE_ROOTFS}/data$(dirname $conf)
        if [ -e ${IMAGE_ROOTFS}$conf ]; then
            mv ${IMAGE_ROOTFS}$conf ${IMAGE_ROOTFS}/data$conf
        else
            # conf is a directory
            if echo $conf | grep -o -q '^.*/$'; then
                mkdir -p ${IMAGE_ROOTFS}/data$conf
            else
                touch ${IMAGE_ROOTFS}/data$conf
            fi
        fi
        ln -sf /data$conf ${IMAGE_ROOTFS}$(echo $conf | sed -e 's/\/$//')
    done
}

# Create persistent symbolic links
ROOTFS_POSTPROCESS_COMMAND += "create_persistent_symbolic_links ;"
